@@ -3,7 +3,7 @@ from typing import Dict
 import attr
 import requests
 
-BASE_URL = "http://platform-akki.recital.ai:8000"
+BASE_URL = "http://sandbox.platform.recital.ai:8000"
 
 
 @attr.s(auto_attribs=True)
