@@ -4,6 +4,7 @@ from .access_token import AccessToken
 from .analyzer_language import AnalyzerLanguage
 from .archive_type import ArchiveType
 from .archives_out import ArchivesOut
+from .b_box import BBox
 from .background_task_in import BackgroundTaskIn
 from .background_task_out import BackgroundTaskOut
 from .background_task_update_items import BackgroundTaskUpdateItems
@@ -41,6 +42,7 @@ from .chunk_bookmark_result import ChunkBookmarkResult
 from .chunk_collection_create import ChunkCollectionCreate
 from .chunk_collection_out import ChunkCollectionOut
 from .chunk_collection_update import ChunkCollectionUpdate
+from .chunk_entities import ChunkEntities
 from .chunk_out import ChunkOut
 from .chunk_out_coordinates import ChunkOutCoordinates
 from .chunk_out_div_idxs import ChunkOutDivIdxs
@@ -109,6 +111,7 @@ from .extract_top_chunk_validate_out_coordinates import ExtractTopChunkValidateO
 from .extract_top_chunk_validate_out_div_idxs import ExtractTopChunkValidateOutDivIdxs
 from .extract_type import ExtractType
 from .extract_value_config import ExtractValueConfig
+from .extract_with_config_out import ExtractWithConfigOut
 from .file_item_move import FileItemMove
 from .file_item_out import FileItemOut
 from .file_item_out_with_latest_version import FileItemOutWithLatestVersion
@@ -123,8 +126,6 @@ from .folder_out_by_group import FolderOutByGroup
 from .folder_right import FolderRight
 from .folder_update import FolderUpdate
 from .full_password_policy import FullPasswordPolicy
-from .get_chunks_entities_response_200_item import GetChunksEntitiesResponse_200Item
-from .get_chunks_response_200_item import GetChunksResponse_200Item
 from .get_version_styled_html_pages_response_get_version_styled_html_pages_api_v1_files_versions_version_id_styled_html_get import (
     GetVersionStyledHtmlPagesResponseGetVersionStyledHtmlPagesApiV1FilesVersionsVersionIdStyledHtmlGet,
 )
@@ -190,7 +191,6 @@ from .password_policy_update import PasswordPolicyUpdate
 from .password_update_login import PasswordUpdateLogin
 from .permission import Permission
 from .permission_update import PermissionUpdate
-from .post_synchronous_extract_task_response_200_item import PostSynchronousExtractTaskResponse_200Item
 from .product import Product
 from .questionnaire import Questionnaire
 from .questionnaire_create import QuestionnaireCreate
@@ -214,9 +214,7 @@ from .search_query_out_filters import SearchQueryOutFilters
 from .search_query_string_query import SearchQueryStringQuery
 from .search_query_string_query_filters import SearchQueryStringQueryFilters
 from .search_result_chunks import SearchResultChunks
-from .search_result_chunks_chunks_item import SearchResultChunksChunksItem
 from .search_result_documents import SearchResultDocuments
-from .search_result_documents_documents_item import SearchResultDocumentsDocumentsItem
 from .search_result_pipeline_logs import SearchResultPipelineLogs
 from .search_result_pipeline_logs_borda_chunks import SearchResultPipelineLogsBordaChunks
 from .search_result_pipeline_logs_documents import SearchResultPipelineLogsDocuments
